"""
Generated by generate/generate.py - 2020-08-02 10:38:59.444717
"""
from aiogithubapi.objects.repos.fork import AIOGitHubAPIReposFork

from tests.legacy.responses.repos.fork_fixtrue import fork_fixtrue_response


def test_fork(fork_fixtrue_response):
    obj = AIOGitHubAPIReposFork(fork_fixtrue_response)
    assert obj.id == fork_fixtrue_response["id"]
    assert obj.node_id == fork_fixtrue_response["node_id"]
    assert obj.name == fork_fixtrue_response["name"]
    assert obj.full_name == fork_fixtrue_response["full_name"]
    assert obj.owner.login == fork_fixtrue_response["owner"]["login"]
    assert obj.owner.id == fork_fixtrue_response["owner"]["id"]
    assert obj.owner.node_id == fork_fixtrue_response["owner"]["node_id"]
    assert obj.owner.avatar_url == fork_fixtrue_response["owner"]["avatar_url"]
    assert obj.owner.gravatar_id == fork_fixtrue_response["owner"]["gravatar_id"]
    assert obj.owner.url == fork_fixtrue_response["owner"]["url"]
    assert obj.owner.html_url == fork_fixtrue_response["owner"]["html_url"]
    assert obj.owner.followers_url == fork_fixtrue_response["owner"]["followers_url"]
    assert obj.owner.following_url == fork_fixtrue_response["owner"]["following_url"]
    assert obj.owner.gists_url == fork_fixtrue_response["owner"]["gists_url"]
    assert obj.owner.starred_url == fork_fixtrue_response["owner"]["starred_url"]
    assert obj.owner.subscriptions_url == fork_fixtrue_response["owner"]["subscriptions_url"]
    assert obj.owner.organizations_url == fork_fixtrue_response["owner"]["organizations_url"]
    assert obj.owner.repos_url == fork_fixtrue_response["owner"]["repos_url"]
    assert obj.owner.events_url == fork_fixtrue_response["owner"]["events_url"]
    assert obj.owner.received_events_url == fork_fixtrue_response["owner"]["received_events_url"]
    assert obj.owner.type == fork_fixtrue_response["owner"]["type"]
    assert obj.owner.site_admin == fork_fixtrue_response["owner"]["site_admin"]
    assert obj.private == fork_fixtrue_response["private"]
    assert obj.html_url == fork_fixtrue_response["html_url"]
    assert obj.description == fork_fixtrue_response["description"]
    assert obj.fork == fork_fixtrue_response["fork"]
    assert obj.url == fork_fixtrue_response["url"]
    assert obj.archive_url == fork_fixtrue_response["archive_url"]
    assert obj.assignees_url == fork_fixtrue_response["assignees_url"]
    assert obj.blobs_url == fork_fixtrue_response["blobs_url"]
    assert obj.branches_url == fork_fixtrue_response["branches_url"]
    assert obj.collaborators_url == fork_fixtrue_response["collaborators_url"]
    assert obj.comments_url == fork_fixtrue_response["comments_url"]
    assert obj.commits_url == fork_fixtrue_response["commits_url"]
    assert obj.compare_url == fork_fixtrue_response["compare_url"]
    assert obj.contents_url == fork_fixtrue_response["contents_url"]
    assert obj.contributors_url == fork_fixtrue_response["contributors_url"]
    assert obj.deployments_url == fork_fixtrue_response["deployments_url"]
    assert obj.downloads_url == fork_fixtrue_response["downloads_url"]
    assert obj.events_url == fork_fixtrue_response["events_url"]
    assert obj.forks_url == fork_fixtrue_response["forks_url"]
    assert obj.git_commits_url == fork_fixtrue_response["git_commits_url"]
    assert obj.git_refs_url == fork_fixtrue_response["git_refs_url"]
    assert obj.git_tags_url == fork_fixtrue_response["git_tags_url"]
    assert obj.git_url == fork_fixtrue_response["git_url"]
    assert obj.issue_comment_url == fork_fixtrue_response["issue_comment_url"]
    assert obj.issue_events_url == fork_fixtrue_response["issue_events_url"]
    assert obj.issues_url == fork_fixtrue_response["issues_url"]
    assert obj.keys_url == fork_fixtrue_response["keys_url"]
    assert obj.labels_url == fork_fixtrue_response["labels_url"]
    assert obj.languages_url == fork_fixtrue_response["languages_url"]
    assert obj.merges_url == fork_fixtrue_response["merges_url"]
    assert obj.milestones_url == fork_fixtrue_response["milestones_url"]
    assert obj.notifications_url == fork_fixtrue_response["notifications_url"]
    assert obj.pulls_url == fork_fixtrue_response["pulls_url"]
    assert obj.releases_url == fork_fixtrue_response["releases_url"]
    assert obj.ssh_url == fork_fixtrue_response["ssh_url"]
    assert obj.stargazers_url == fork_fixtrue_response["stargazers_url"]
    assert obj.statuses_url == fork_fixtrue_response["statuses_url"]
    assert obj.subscribers_url == fork_fixtrue_response["subscribers_url"]
    assert obj.subscription_url == fork_fixtrue_response["subscription_url"]
    assert obj.tags_url == fork_fixtrue_response["tags_url"]
    assert obj.teams_url == fork_fixtrue_response["teams_url"]
    assert obj.trees_url == fork_fixtrue_response["trees_url"]
    assert obj.clone_url == fork_fixtrue_response["clone_url"]
    assert obj.mirror_url == fork_fixtrue_response["mirror_url"]
    assert obj.hooks_url == fork_fixtrue_response["hooks_url"]
    assert obj.svn_url == fork_fixtrue_response["svn_url"]
    assert obj.homepage == fork_fixtrue_response["homepage"]
    assert obj.language == fork_fixtrue_response["language"]
    assert obj.forks_count == fork_fixtrue_response["forks_count"]
    assert obj.stargazers_count == fork_fixtrue_response["stargazers_count"]
    assert obj.watchers_count == fork_fixtrue_response["watchers_count"]
    assert obj.size == fork_fixtrue_response["size"]
    assert obj.default_branch == fork_fixtrue_response["default_branch"]
    assert obj.open_issues_count == fork_fixtrue_response["open_issues_count"]
    assert obj.is_template == fork_fixtrue_response["is_template"]
    assert obj.topics[0] == fork_fixtrue_response["topics"][0]
    assert obj.has_issues == fork_fixtrue_response["has_issues"]
    assert obj.has_projects == fork_fixtrue_response["has_projects"]
    assert obj.has_wiki == fork_fixtrue_response["has_wiki"]
    assert obj.has_pages == fork_fixtrue_response["has_pages"]
    assert obj.has_downloads == fork_fixtrue_response["has_downloads"]
    assert obj.archived == fork_fixtrue_response["archived"]
    assert obj.disabled == fork_fixtrue_response["disabled"]
    assert obj.visibility == fork_fixtrue_response["visibility"]
    assert obj.pushed_at == fork_fixtrue_response["pushed_at"]
    assert obj.created_at == fork_fixtrue_response["created_at"]
    assert obj.updated_at == fork_fixtrue_response["updated_at"]
    assert obj.permissions.admin == fork_fixtrue_response["permissions"]["admin"]
    assert obj.permissions.push == fork_fixtrue_response["permissions"]["push"]
    assert obj.permissions.pull == fork_fixtrue_response["permissions"]["pull"]
    assert obj.template_repository == fork_fixtrue_response["template_repository"]
    assert obj.temp_clone_token == fork_fixtrue_response["temp_clone_token"]
    assert obj.delete_branch_on_merge == fork_fixtrue_response["delete_branch_on_merge"]
    assert obj.subscribers_count == fork_fixtrue_response["subscribers_count"]
    assert obj.network_count == fork_fixtrue_response["network_count"]
    assert obj.license.key == fork_fixtrue_response["license"]["key"]
    assert obj.license.name == fork_fixtrue_response["license"]["name"]
    assert obj.license.spdx_id == fork_fixtrue_response["license"]["spdx_id"]
    assert obj.license.url == fork_fixtrue_response["license"]["url"]
    assert obj.license.node_id == fork_fixtrue_response["license"]["node_id"]
