"""
Generated by generate/generate.py - 2020-09-08 18:45:20.581868
"""
from aiogithubapi.objects.login.oauth import AIOGitHubAPILoginOauth

from tests.legacy.responses.login.oauth_fixtrue import oauth_fixtrue_response


def test_oauth(oauth_fixtrue_response):
    obj = AIOGitHubAPILoginOauth(oauth_fixtrue_response)
    assert obj.access_token == oauth_fixtrue_response["access_token"]
    assert obj.token_type == oauth_fixtrue_response["token_type"]
    assert obj.scope == oauth_fixtrue_response["scope"]
