"""
Class object for AIOGitHubAPILoginDevice
Documentation: https://docs.github.com/en/developers/apps/authorizing-oauth-apps#device-flow

Generated by generate/generate.py - 2020-09-08 17:49:51.525706
"""

from ..base import AIOGitHubAPIBase


class AIOGitHubAPILoginDevice(AIOGitHubAPIBase):
    @property
    def device_code(self):
        return self.attributes.get("device_code", "")

    @property
    def user_code(self):
        return self.attributes.get("user_code", "")

    @property
    def verification_uri(self):
        return self.attributes.get("verification_uri", "")

    @property
    def expires_in(self):
        return self.attributes.get("expires_in", None)

    @property
    def interval(self):
        return self.attributes.get("interval", None)
