"""
Generated by generate/generate.py - 2020-08-02 10:03:59.857088
"""
from aiogithubapi.objects.repository.pullrequest import (
    AIOGitHubAPIRepositoryPullrequest,
)

from tests.legacy.responses.repository.pullrequest_fixtrue import (
    pullrequest_fixtrue_response,
)


def test_pullrequest(pullrequest_fixtrue_response):
    obj = AIOGitHubAPIRepositoryPullrequest(pullrequest_fixtrue_response)
    assert obj.url == pullrequest_fixtrue_response["url"]
    assert obj.id == pullrequest_fixtrue_response["id"]
    assert obj.node_id == pullrequest_fixtrue_response["node_id"]
    assert obj.html_url == pullrequest_fixtrue_response["html_url"]
    assert obj.diff_url == pullrequest_fixtrue_response["diff_url"]
    assert obj.patch_url == pullrequest_fixtrue_response["patch_url"]
    assert obj.issue_url == pullrequest_fixtrue_response["issue_url"]
    assert obj.commits_url == pullrequest_fixtrue_response["commits_url"]
    assert obj.review_comments_url == pullrequest_fixtrue_response["review_comments_url"]
    assert obj.review_comment_url == pullrequest_fixtrue_response["review_comment_url"]
    assert obj.comments_url == pullrequest_fixtrue_response["comments_url"]
    assert obj.statuses_url == pullrequest_fixtrue_response["statuses_url"]
    assert obj.number == pullrequest_fixtrue_response["number"]
    assert obj.state == pullrequest_fixtrue_response["state"]
    assert obj.locked == pullrequest_fixtrue_response["locked"]
    assert obj.title == pullrequest_fixtrue_response["title"]
    assert obj.user.login == pullrequest_fixtrue_response["user"]["login"]
    assert obj.user.id == pullrequest_fixtrue_response["user"]["id"]
    assert obj.user.node_id == pullrequest_fixtrue_response["user"]["node_id"]
    assert obj.user.avatar_url == pullrequest_fixtrue_response["user"]["avatar_url"]
    assert obj.user.gravatar_id == pullrequest_fixtrue_response["user"]["gravatar_id"]
    assert obj.user.url == pullrequest_fixtrue_response["user"]["url"]
    assert obj.user.html_url == pullrequest_fixtrue_response["user"]["html_url"]
    assert obj.user.followers_url == pullrequest_fixtrue_response["user"]["followers_url"]
    assert obj.user.following_url == pullrequest_fixtrue_response["user"]["following_url"]
    assert obj.user.gists_url == pullrequest_fixtrue_response["user"]["gists_url"]
    assert obj.user.starred_url == pullrequest_fixtrue_response["user"]["starred_url"]
    assert obj.user.subscriptions_url == pullrequest_fixtrue_response["user"]["subscriptions_url"]
    assert obj.user.organizations_url == pullrequest_fixtrue_response["user"]["organizations_url"]
    assert obj.user.repos_url == pullrequest_fixtrue_response["user"]["repos_url"]
    assert obj.user.events_url == pullrequest_fixtrue_response["user"]["events_url"]
    assert (
        obj.user.received_events_url == pullrequest_fixtrue_response["user"]["received_events_url"]
    )
    assert obj.user.type == pullrequest_fixtrue_response["user"]["type"]
    assert obj.user.site_admin == pullrequest_fixtrue_response["user"]["site_admin"]
    assert obj.body == pullrequest_fixtrue_response["body"]
    assert obj.labels[0].id == pullrequest_fixtrue_response["labels"][0]["id"]
    assert obj.labels[0].node_id == pullrequest_fixtrue_response["labels"][0]["node_id"]
    assert obj.labels[0].url == pullrequest_fixtrue_response["labels"][0]["url"]
    assert obj.labels[0].name == pullrequest_fixtrue_response["labels"][0]["name"]
    assert obj.labels[0].description == pullrequest_fixtrue_response["labels"][0]["description"]
    assert obj.labels[0].color == pullrequest_fixtrue_response["labels"][0]["color"]
    assert obj.labels[0].default == pullrequest_fixtrue_response["labels"][0]["default"]
    assert obj.milestone.url == pullrequest_fixtrue_response["milestone"]["url"]
    assert obj.milestone.html_url == pullrequest_fixtrue_response["milestone"]["html_url"]
    assert obj.milestone.labels_url == pullrequest_fixtrue_response["milestone"]["labels_url"]
    assert obj.milestone.id == pullrequest_fixtrue_response["milestone"]["id"]
    assert obj.milestone.node_id == pullrequest_fixtrue_response["milestone"]["node_id"]
    assert obj.milestone.number == pullrequest_fixtrue_response["milestone"]["number"]
    assert obj.milestone.state == pullrequest_fixtrue_response["milestone"]["state"]
    assert obj.milestone.title == pullrequest_fixtrue_response["milestone"]["title"]
    assert obj.milestone.description == pullrequest_fixtrue_response["milestone"]["description"]
    assert (
        obj.milestone.creator.login == pullrequest_fixtrue_response["milestone"]["creator"]["login"]
    )
    assert obj.milestone.creator.id == pullrequest_fixtrue_response["milestone"]["creator"]["id"]
    assert (
        obj.milestone.creator.node_id
        == pullrequest_fixtrue_response["milestone"]["creator"]["node_id"]
    )
    assert (
        obj.milestone.creator.avatar_url
        == pullrequest_fixtrue_response["milestone"]["creator"]["avatar_url"]
    )
    assert (
        obj.milestone.creator.gravatar_id
        == pullrequest_fixtrue_response["milestone"]["creator"]["gravatar_id"]
    )
    assert obj.milestone.creator.url == pullrequest_fixtrue_response["milestone"]["creator"]["url"]
    assert (
        obj.milestone.creator.html_url
        == pullrequest_fixtrue_response["milestone"]["creator"]["html_url"]
    )
    assert (
        obj.milestone.creator.followers_url
        == pullrequest_fixtrue_response["milestone"]["creator"]["followers_url"]
    )
    assert (
        obj.milestone.creator.following_url
        == pullrequest_fixtrue_response["milestone"]["creator"]["following_url"]
    )
    assert (
        obj.milestone.creator.gists_url
        == pullrequest_fixtrue_response["milestone"]["creator"]["gists_url"]
    )
    assert (
        obj.milestone.creator.starred_url
        == pullrequest_fixtrue_response["milestone"]["creator"]["starred_url"]
    )
    assert (
        obj.milestone.creator.subscriptions_url
        == pullrequest_fixtrue_response["milestone"]["creator"]["subscriptions_url"]
    )
    assert (
        obj.milestone.creator.organizations_url
        == pullrequest_fixtrue_response["milestone"]["creator"]["organizations_url"]
    )
    assert (
        obj.milestone.creator.repos_url
        == pullrequest_fixtrue_response["milestone"]["creator"]["repos_url"]
    )
    assert (
        obj.milestone.creator.events_url
        == pullrequest_fixtrue_response["milestone"]["creator"]["events_url"]
    )
    assert (
        obj.milestone.creator.received_events_url
        == pullrequest_fixtrue_response["milestone"]["creator"]["received_events_url"]
    )
    assert (
        obj.milestone.creator.type == pullrequest_fixtrue_response["milestone"]["creator"]["type"]
    )
    assert (
        obj.milestone.creator.site_admin
        == pullrequest_fixtrue_response["milestone"]["creator"]["site_admin"]
    )
    assert obj.milestone.open_issues == pullrequest_fixtrue_response["milestone"]["open_issues"]
    assert obj.milestone.closed_issues == pullrequest_fixtrue_response["milestone"]["closed_issues"]
    assert obj.milestone.created_at == pullrequest_fixtrue_response["milestone"]["created_at"]
    assert obj.milestone.updated_at == pullrequest_fixtrue_response["milestone"]["updated_at"]
    assert obj.milestone.closed_at == pullrequest_fixtrue_response["milestone"]["closed_at"]
    assert obj.milestone.due_on == pullrequest_fixtrue_response["milestone"]["due_on"]
    assert obj.active_lock_reason == pullrequest_fixtrue_response["active_lock_reason"]
    assert obj.created_at == pullrequest_fixtrue_response["created_at"]
    assert obj.updated_at == pullrequest_fixtrue_response["updated_at"]
    assert obj.closed_at == pullrequest_fixtrue_response["closed_at"]
    assert obj.merged_at == pullrequest_fixtrue_response["merged_at"]
    assert obj.merge_commit_sha == pullrequest_fixtrue_response["merge_commit_sha"]
    assert obj.assignee.login == pullrequest_fixtrue_response["assignee"]["login"]
    assert obj.assignee.id == pullrequest_fixtrue_response["assignee"]["id"]
    assert obj.assignee.node_id == pullrequest_fixtrue_response["assignee"]["node_id"]
    assert obj.assignee.avatar_url == pullrequest_fixtrue_response["assignee"]["avatar_url"]
    assert obj.assignee.gravatar_id == pullrequest_fixtrue_response["assignee"]["gravatar_id"]
    assert obj.assignee.url == pullrequest_fixtrue_response["assignee"]["url"]
    assert obj.assignee.html_url == pullrequest_fixtrue_response["assignee"]["html_url"]
    assert obj.assignee.followers_url == pullrequest_fixtrue_response["assignee"]["followers_url"]
    assert obj.assignee.following_url == pullrequest_fixtrue_response["assignee"]["following_url"]
    assert obj.assignee.gists_url == pullrequest_fixtrue_response["assignee"]["gists_url"]
    assert obj.assignee.starred_url == pullrequest_fixtrue_response["assignee"]["starred_url"]
    assert (
        obj.assignee.subscriptions_url
        == pullrequest_fixtrue_response["assignee"]["subscriptions_url"]
    )
    assert (
        obj.assignee.organizations_url
        == pullrequest_fixtrue_response["assignee"]["organizations_url"]
    )
    assert obj.assignee.repos_url == pullrequest_fixtrue_response["assignee"]["repos_url"]
    assert obj.assignee.events_url == pullrequest_fixtrue_response["assignee"]["events_url"]
    assert (
        obj.assignee.received_events_url
        == pullrequest_fixtrue_response["assignee"]["received_events_url"]
    )
    assert obj.assignee.type == pullrequest_fixtrue_response["assignee"]["type"]
    assert obj.assignee.site_admin == pullrequest_fixtrue_response["assignee"]["site_admin"]
    assert obj.assignees[0].login == pullrequest_fixtrue_response["assignees"][0]["login"]
    assert obj.assignees[0].id == pullrequest_fixtrue_response["assignees"][0]["id"]
    assert obj.assignees[0].node_id == pullrequest_fixtrue_response["assignees"][0]["node_id"]
    assert obj.assignees[0].avatar_url == pullrequest_fixtrue_response["assignees"][0]["avatar_url"]
    assert (
        obj.assignees[0].gravatar_id == pullrequest_fixtrue_response["assignees"][0]["gravatar_id"]
    )
    assert obj.assignees[0].url == pullrequest_fixtrue_response["assignees"][0]["url"]
    assert obj.assignees[0].html_url == pullrequest_fixtrue_response["assignees"][0]["html_url"]
    assert (
        obj.assignees[0].followers_url
        == pullrequest_fixtrue_response["assignees"][0]["followers_url"]
    )
    assert (
        obj.assignees[0].following_url
        == pullrequest_fixtrue_response["assignees"][0]["following_url"]
    )
    assert obj.assignees[0].gists_url == pullrequest_fixtrue_response["assignees"][0]["gists_url"]
    assert (
        obj.assignees[0].starred_url == pullrequest_fixtrue_response["assignees"][0]["starred_url"]
    )
    assert (
        obj.assignees[0].subscriptions_url
        == pullrequest_fixtrue_response["assignees"][0]["subscriptions_url"]
    )
    assert (
        obj.assignees[0].organizations_url
        == pullrequest_fixtrue_response["assignees"][0]["organizations_url"]
    )
    assert obj.assignees[0].repos_url == pullrequest_fixtrue_response["assignees"][0]["repos_url"]
    assert obj.assignees[0].events_url == pullrequest_fixtrue_response["assignees"][0]["events_url"]
    assert (
        obj.assignees[0].received_events_url
        == pullrequest_fixtrue_response["assignees"][0]["received_events_url"]
    )
    assert obj.assignees[0].type == pullrequest_fixtrue_response["assignees"][0]["type"]
    assert obj.assignees[0].site_admin == pullrequest_fixtrue_response["assignees"][0]["site_admin"]
    assert (
        obj.requested_reviewers[0].login
        == pullrequest_fixtrue_response["requested_reviewers"][0]["login"]
    )
    assert (
        obj.requested_reviewers[0].id
        == pullrequest_fixtrue_response["requested_reviewers"][0]["id"]
    )
    assert (
        obj.requested_reviewers[0].node_id
        == pullrequest_fixtrue_response["requested_reviewers"][0]["node_id"]
    )
    assert (
        obj.requested_reviewers[0].avatar_url
        == pullrequest_fixtrue_response["requested_reviewers"][0]["avatar_url"]
    )
    assert (
        obj.requested_reviewers[0].gravatar_id
        == pullrequest_fixtrue_response["requested_reviewers"][0]["gravatar_id"]
    )
    assert (
        obj.requested_reviewers[0].url
        == pullrequest_fixtrue_response["requested_reviewers"][0]["url"]
    )
    assert (
        obj.requested_reviewers[0].html_url
        == pullrequest_fixtrue_response["requested_reviewers"][0]["html_url"]
    )
    assert (
        obj.requested_reviewers[0].followers_url
        == pullrequest_fixtrue_response["requested_reviewers"][0]["followers_url"]
    )
    assert (
        obj.requested_reviewers[0].following_url
        == pullrequest_fixtrue_response["requested_reviewers"][0]["following_url"]
    )
    assert (
        obj.requested_reviewers[0].gists_url
        == pullrequest_fixtrue_response["requested_reviewers"][0]["gists_url"]
    )
    assert (
        obj.requested_reviewers[0].starred_url
        == pullrequest_fixtrue_response["requested_reviewers"][0]["starred_url"]
    )
    assert (
        obj.requested_reviewers[0].subscriptions_url
        == pullrequest_fixtrue_response["requested_reviewers"][0]["subscriptions_url"]
    )
    assert (
        obj.requested_reviewers[0].organizations_url
        == pullrequest_fixtrue_response["requested_reviewers"][0]["organizations_url"]
    )
    assert (
        obj.requested_reviewers[0].repos_url
        == pullrequest_fixtrue_response["requested_reviewers"][0]["repos_url"]
    )
    assert (
        obj.requested_reviewers[0].events_url
        == pullrequest_fixtrue_response["requested_reviewers"][0]["events_url"]
    )
    assert (
        obj.requested_reviewers[0].received_events_url
        == pullrequest_fixtrue_response["requested_reviewers"][0]["received_events_url"]
    )
    assert (
        obj.requested_reviewers[0].type
        == pullrequest_fixtrue_response["requested_reviewers"][0]["type"]
    )
    assert (
        obj.requested_reviewers[0].site_admin
        == pullrequest_fixtrue_response["requested_reviewers"][0]["site_admin"]
    )
    assert obj.requested_teams[0].id == pullrequest_fixtrue_response["requested_teams"][0]["id"]
    assert (
        obj.requested_teams[0].node_id
        == pullrequest_fixtrue_response["requested_teams"][0]["node_id"]
    )
    assert obj.requested_teams[0].url == pullrequest_fixtrue_response["requested_teams"][0]["url"]
    assert (
        obj.requested_teams[0].html_url
        == pullrequest_fixtrue_response["requested_teams"][0]["html_url"]
    )
    assert obj.requested_teams[0].name == pullrequest_fixtrue_response["requested_teams"][0]["name"]
    assert obj.requested_teams[0].slug == pullrequest_fixtrue_response["requested_teams"][0]["slug"]
    assert (
        obj.requested_teams[0].description
        == pullrequest_fixtrue_response["requested_teams"][0]["description"]
    )
    assert (
        obj.requested_teams[0].privacy
        == pullrequest_fixtrue_response["requested_teams"][0]["privacy"]
    )
    assert (
        obj.requested_teams[0].permission
        == pullrequest_fixtrue_response["requested_teams"][0]["permission"]
    )
    assert (
        obj.requested_teams[0].members_url
        == pullrequest_fixtrue_response["requested_teams"][0]["members_url"]
    )
    assert (
        obj.requested_teams[0].repositories_url
        == pullrequest_fixtrue_response["requested_teams"][0]["repositories_url"]
    )
    assert (
        obj.requested_teams[0].parent
        == pullrequest_fixtrue_response["requested_teams"][0]["parent"]
    )
    assert obj.head.label == pullrequest_fixtrue_response["head"]["label"]
    assert obj.head.ref == pullrequest_fixtrue_response["head"]["ref"]
    assert obj.head.sha == pullrequest_fixtrue_response["head"]["sha"]
    assert obj.head.user.login == pullrequest_fixtrue_response["head"]["user"]["login"]
    assert obj.head.user.id == pullrequest_fixtrue_response["head"]["user"]["id"]
    assert obj.head.user.node_id == pullrequest_fixtrue_response["head"]["user"]["node_id"]
    assert obj.head.user.avatar_url == pullrequest_fixtrue_response["head"]["user"]["avatar_url"]
    assert obj.head.user.gravatar_id == pullrequest_fixtrue_response["head"]["user"]["gravatar_id"]
    assert obj.head.user.url == pullrequest_fixtrue_response["head"]["user"]["url"]
    assert obj.head.user.html_url == pullrequest_fixtrue_response["head"]["user"]["html_url"]
    assert (
        obj.head.user.followers_url == pullrequest_fixtrue_response["head"]["user"]["followers_url"]
    )
    assert (
        obj.head.user.following_url == pullrequest_fixtrue_response["head"]["user"]["following_url"]
    )
    assert obj.head.user.gists_url == pullrequest_fixtrue_response["head"]["user"]["gists_url"]
    assert obj.head.user.starred_url == pullrequest_fixtrue_response["head"]["user"]["starred_url"]
    assert (
        obj.head.user.subscriptions_url
        == pullrequest_fixtrue_response["head"]["user"]["subscriptions_url"]
    )
    assert (
        obj.head.user.organizations_url
        == pullrequest_fixtrue_response["head"]["user"]["organizations_url"]
    )
    assert obj.head.user.repos_url == pullrequest_fixtrue_response["head"]["user"]["repos_url"]
    assert obj.head.user.events_url == pullrequest_fixtrue_response["head"]["user"]["events_url"]
    assert (
        obj.head.user.received_events_url
        == pullrequest_fixtrue_response["head"]["user"]["received_events_url"]
    )
    assert obj.head.user.type == pullrequest_fixtrue_response["head"]["user"]["type"]
    assert obj.head.user.site_admin == pullrequest_fixtrue_response["head"]["user"]["site_admin"]
    assert obj.head.repo.id == pullrequest_fixtrue_response["head"]["repo"]["id"]
    assert obj.head.repo.node_id == pullrequest_fixtrue_response["head"]["repo"]["node_id"]
    assert obj.head.repo.name == pullrequest_fixtrue_response["head"]["repo"]["name"]
    assert obj.head.repo.full_name == pullrequest_fixtrue_response["head"]["repo"]["full_name"]
    assert (
        obj.head.repo.owner.login == pullrequest_fixtrue_response["head"]["repo"]["owner"]["login"]
    )
    assert obj.head.repo.owner.id == pullrequest_fixtrue_response["head"]["repo"]["owner"]["id"]
    assert (
        obj.head.repo.owner.node_id
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["node_id"]
    )
    assert (
        obj.head.repo.owner.avatar_url
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["avatar_url"]
    )
    assert (
        obj.head.repo.owner.gravatar_id
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["gravatar_id"]
    )
    assert obj.head.repo.owner.url == pullrequest_fixtrue_response["head"]["repo"]["owner"]["url"]
    assert (
        obj.head.repo.owner.html_url
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["html_url"]
    )
    assert (
        obj.head.repo.owner.followers_url
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["followers_url"]
    )
    assert (
        obj.head.repo.owner.following_url
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["following_url"]
    )
    assert (
        obj.head.repo.owner.gists_url
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["gists_url"]
    )
    assert (
        obj.head.repo.owner.starred_url
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["starred_url"]
    )
    assert (
        obj.head.repo.owner.subscriptions_url
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["subscriptions_url"]
    )
    assert (
        obj.head.repo.owner.organizations_url
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["organizations_url"]
    )
    assert (
        obj.head.repo.owner.repos_url
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["repos_url"]
    )
    assert (
        obj.head.repo.owner.events_url
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["events_url"]
    )
    assert (
        obj.head.repo.owner.received_events_url
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["received_events_url"]
    )
    assert obj.head.repo.owner.type == pullrequest_fixtrue_response["head"]["repo"]["owner"]["type"]
    assert (
        obj.head.repo.owner.site_admin
        == pullrequest_fixtrue_response["head"]["repo"]["owner"]["site_admin"]
    )
    assert obj.head.repo.private == pullrequest_fixtrue_response["head"]["repo"]["private"]
    assert obj.head.repo.html_url == pullrequest_fixtrue_response["head"]["repo"]["html_url"]
    assert obj.head.repo.description == pullrequest_fixtrue_response["head"]["repo"]["description"]
    assert obj.head.repo.fork == pullrequest_fixtrue_response["head"]["repo"]["fork"]
    assert obj.head.repo.url == pullrequest_fixtrue_response["head"]["repo"]["url"]
    assert obj.head.repo.archive_url == pullrequest_fixtrue_response["head"]["repo"]["archive_url"]
    assert (
        obj.head.repo.assignees_url == pullrequest_fixtrue_response["head"]["repo"]["assignees_url"]
    )
    assert obj.head.repo.blobs_url == pullrequest_fixtrue_response["head"]["repo"]["blobs_url"]
    assert (
        obj.head.repo.branches_url == pullrequest_fixtrue_response["head"]["repo"]["branches_url"]
    )
    assert (
        obj.head.repo.collaborators_url
        == pullrequest_fixtrue_response["head"]["repo"]["collaborators_url"]
    )
    assert (
        obj.head.repo.comments_url == pullrequest_fixtrue_response["head"]["repo"]["comments_url"]
    )
    assert obj.head.repo.commits_url == pullrequest_fixtrue_response["head"]["repo"]["commits_url"]
    assert obj.head.repo.compare_url == pullrequest_fixtrue_response["head"]["repo"]["compare_url"]
    assert (
        obj.head.repo.contents_url == pullrequest_fixtrue_response["head"]["repo"]["contents_url"]
    )
    assert (
        obj.head.repo.contributors_url
        == pullrequest_fixtrue_response["head"]["repo"]["contributors_url"]
    )
    assert (
        obj.head.repo.deployments_url
        == pullrequest_fixtrue_response["head"]["repo"]["deployments_url"]
    )
    assert (
        obj.head.repo.downloads_url == pullrequest_fixtrue_response["head"]["repo"]["downloads_url"]
    )
    assert obj.head.repo.events_url == pullrequest_fixtrue_response["head"]["repo"]["events_url"]
    assert obj.head.repo.forks_url == pullrequest_fixtrue_response["head"]["repo"]["forks_url"]
    assert (
        obj.head.repo.git_commits_url
        == pullrequest_fixtrue_response["head"]["repo"]["git_commits_url"]
    )
    assert (
        obj.head.repo.git_refs_url == pullrequest_fixtrue_response["head"]["repo"]["git_refs_url"]
    )
    assert (
        obj.head.repo.git_tags_url == pullrequest_fixtrue_response["head"]["repo"]["git_tags_url"]
    )
    assert obj.head.repo.git_url == pullrequest_fixtrue_response["head"]["repo"]["git_url"]
    assert (
        obj.head.repo.issue_comment_url
        == pullrequest_fixtrue_response["head"]["repo"]["issue_comment_url"]
    )
    assert (
        obj.head.repo.issue_events_url
        == pullrequest_fixtrue_response["head"]["repo"]["issue_events_url"]
    )
    assert obj.head.repo.issues_url == pullrequest_fixtrue_response["head"]["repo"]["issues_url"]
    assert obj.head.repo.keys_url == pullrequest_fixtrue_response["head"]["repo"]["keys_url"]
    assert obj.head.repo.labels_url == pullrequest_fixtrue_response["head"]["repo"]["labels_url"]
    assert (
        obj.head.repo.languages_url == pullrequest_fixtrue_response["head"]["repo"]["languages_url"]
    )
    assert obj.head.repo.merges_url == pullrequest_fixtrue_response["head"]["repo"]["merges_url"]
    assert (
        obj.head.repo.milestones_url
        == pullrequest_fixtrue_response["head"]["repo"]["milestones_url"]
    )
    assert (
        obj.head.repo.notifications_url
        == pullrequest_fixtrue_response["head"]["repo"]["notifications_url"]
    )
    assert obj.head.repo.pulls_url == pullrequest_fixtrue_response["head"]["repo"]["pulls_url"]
    assert (
        obj.head.repo.releases_url == pullrequest_fixtrue_response["head"]["repo"]["releases_url"]
    )
    assert obj.head.repo.ssh_url == pullrequest_fixtrue_response["head"]["repo"]["ssh_url"]
    assert (
        obj.head.repo.stargazers_url
        == pullrequest_fixtrue_response["head"]["repo"]["stargazers_url"]
    )
    assert (
        obj.head.repo.statuses_url == pullrequest_fixtrue_response["head"]["repo"]["statuses_url"]
    )
    assert (
        obj.head.repo.subscribers_url
        == pullrequest_fixtrue_response["head"]["repo"]["subscribers_url"]
    )
    assert (
        obj.head.repo.subscription_url
        == pullrequest_fixtrue_response["head"]["repo"]["subscription_url"]
    )
    assert obj.head.repo.tags_url == pullrequest_fixtrue_response["head"]["repo"]["tags_url"]
    assert obj.head.repo.teams_url == pullrequest_fixtrue_response["head"]["repo"]["teams_url"]
    assert obj.head.repo.trees_url == pullrequest_fixtrue_response["head"]["repo"]["trees_url"]
    assert obj.head.repo.clone_url == pullrequest_fixtrue_response["head"]["repo"]["clone_url"]
    assert obj.head.repo.mirror_url == pullrequest_fixtrue_response["head"]["repo"]["mirror_url"]
    assert obj.head.repo.hooks_url == pullrequest_fixtrue_response["head"]["repo"]["hooks_url"]
    assert obj.head.repo.svn_url == pullrequest_fixtrue_response["head"]["repo"]["svn_url"]
    assert obj.head.repo.homepage == pullrequest_fixtrue_response["head"]["repo"]["homepage"]
    assert obj.head.repo.language == pullrequest_fixtrue_response["head"]["repo"]["language"]
    assert obj.head.repo.forks_count == pullrequest_fixtrue_response["head"]["repo"]["forks_count"]
    assert (
        obj.head.repo.stargazers_count
        == pullrequest_fixtrue_response["head"]["repo"]["stargazers_count"]
    )
    assert (
        obj.head.repo.watchers_count
        == pullrequest_fixtrue_response["head"]["repo"]["watchers_count"]
    )
    assert obj.head.repo.size == pullrequest_fixtrue_response["head"]["repo"]["size"]
    assert (
        obj.head.repo.default_branch
        == pullrequest_fixtrue_response["head"]["repo"]["default_branch"]
    )
    assert (
        obj.head.repo.open_issues_count
        == pullrequest_fixtrue_response["head"]["repo"]["open_issues_count"]
    )
    assert obj.head.repo.is_template == pullrequest_fixtrue_response["head"]["repo"]["is_template"]
    assert obj.head.repo.topics[0] == pullrequest_fixtrue_response["head"]["repo"]["topics"][0]
    assert obj.head.repo.has_issues == pullrequest_fixtrue_response["head"]["repo"]["has_issues"]
    assert (
        obj.head.repo.has_projects == pullrequest_fixtrue_response["head"]["repo"]["has_projects"]
    )
    assert obj.head.repo.has_wiki == pullrequest_fixtrue_response["head"]["repo"]["has_wiki"]
    assert obj.head.repo.has_pages == pullrequest_fixtrue_response["head"]["repo"]["has_pages"]
    assert (
        obj.head.repo.has_downloads == pullrequest_fixtrue_response["head"]["repo"]["has_downloads"]
    )
    assert obj.head.repo.archived == pullrequest_fixtrue_response["head"]["repo"]["archived"]
    assert obj.head.repo.disabled == pullrequest_fixtrue_response["head"]["repo"]["disabled"]
    assert obj.head.repo.visibility == pullrequest_fixtrue_response["head"]["repo"]["visibility"]
    assert obj.head.repo.pushed_at == pullrequest_fixtrue_response["head"]["repo"]["pushed_at"]
    assert obj.head.repo.created_at == pullrequest_fixtrue_response["head"]["repo"]["created_at"]
    assert obj.head.repo.updated_at == pullrequest_fixtrue_response["head"]["repo"]["updated_at"]
    assert (
        obj.head.repo.permissions.admin
        == pullrequest_fixtrue_response["head"]["repo"]["permissions"]["admin"]
    )
    assert (
        obj.head.repo.permissions.push
        == pullrequest_fixtrue_response["head"]["repo"]["permissions"]["push"]
    )
    assert (
        obj.head.repo.permissions.pull
        == pullrequest_fixtrue_response["head"]["repo"]["permissions"]["pull"]
    )
    assert (
        obj.head.repo.allow_rebase_merge
        == pullrequest_fixtrue_response["head"]["repo"]["allow_rebase_merge"]
    )
    assert (
        obj.head.repo.template_repository
        == pullrequest_fixtrue_response["head"]["repo"]["template_repository"]
    )
    assert (
        obj.head.repo.temp_clone_token
        == pullrequest_fixtrue_response["head"]["repo"]["temp_clone_token"]
    )
    assert (
        obj.head.repo.allow_squash_merge
        == pullrequest_fixtrue_response["head"]["repo"]["allow_squash_merge"]
    )
    assert (
        obj.head.repo.delete_branch_on_merge
        == pullrequest_fixtrue_response["head"]["repo"]["delete_branch_on_merge"]
    )
    assert (
        obj.head.repo.allow_merge_commit
        == pullrequest_fixtrue_response["head"]["repo"]["allow_merge_commit"]
    )
    assert (
        obj.head.repo.subscribers_count
        == pullrequest_fixtrue_response["head"]["repo"]["subscribers_count"]
    )
    assert (
        obj.head.repo.network_count == pullrequest_fixtrue_response["head"]["repo"]["network_count"]
    )
    assert obj.base.label == pullrequest_fixtrue_response["base"]["label"]
    assert obj.base.ref == pullrequest_fixtrue_response["base"]["ref"]
    assert obj.base.sha == pullrequest_fixtrue_response["base"]["sha"]
    assert obj.base.user.login == pullrequest_fixtrue_response["base"]["user"]["login"]
    assert obj.base.user.id == pullrequest_fixtrue_response["base"]["user"]["id"]
    assert obj.base.user.node_id == pullrequest_fixtrue_response["base"]["user"]["node_id"]
    assert obj.base.user.avatar_url == pullrequest_fixtrue_response["base"]["user"]["avatar_url"]
    assert obj.base.user.gravatar_id == pullrequest_fixtrue_response["base"]["user"]["gravatar_id"]
    assert obj.base.user.url == pullrequest_fixtrue_response["base"]["user"]["url"]
    assert obj.base.user.html_url == pullrequest_fixtrue_response["base"]["user"]["html_url"]
    assert (
        obj.base.user.followers_url == pullrequest_fixtrue_response["base"]["user"]["followers_url"]
    )
    assert (
        obj.base.user.following_url == pullrequest_fixtrue_response["base"]["user"]["following_url"]
    )
    assert obj.base.user.gists_url == pullrequest_fixtrue_response["base"]["user"]["gists_url"]
    assert obj.base.user.starred_url == pullrequest_fixtrue_response["base"]["user"]["starred_url"]
    assert (
        obj.base.user.subscriptions_url
        == pullrequest_fixtrue_response["base"]["user"]["subscriptions_url"]
    )
    assert (
        obj.base.user.organizations_url
        == pullrequest_fixtrue_response["base"]["user"]["organizations_url"]
    )
    assert obj.base.user.repos_url == pullrequest_fixtrue_response["base"]["user"]["repos_url"]
    assert obj.base.user.events_url == pullrequest_fixtrue_response["base"]["user"]["events_url"]
    assert (
        obj.base.user.received_events_url
        == pullrequest_fixtrue_response["base"]["user"]["received_events_url"]
    )
    assert obj.base.user.type == pullrequest_fixtrue_response["base"]["user"]["type"]
    assert obj.base.user.site_admin == pullrequest_fixtrue_response["base"]["user"]["site_admin"]
    assert obj.base.repo.id == pullrequest_fixtrue_response["base"]["repo"]["id"]
    assert obj.base.repo.node_id == pullrequest_fixtrue_response["base"]["repo"]["node_id"]
    assert obj.base.repo.name == pullrequest_fixtrue_response["base"]["repo"]["name"]
    assert obj.base.repo.full_name == pullrequest_fixtrue_response["base"]["repo"]["full_name"]
    assert (
        obj.base.repo.owner.login == pullrequest_fixtrue_response["base"]["repo"]["owner"]["login"]
    )
    assert obj.base.repo.owner.id == pullrequest_fixtrue_response["base"]["repo"]["owner"]["id"]
    assert (
        obj.base.repo.owner.node_id
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["node_id"]
    )
    assert (
        obj.base.repo.owner.avatar_url
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["avatar_url"]
    )
    assert (
        obj.base.repo.owner.gravatar_id
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["gravatar_id"]
    )
    assert obj.base.repo.owner.url == pullrequest_fixtrue_response["base"]["repo"]["owner"]["url"]
    assert (
        obj.base.repo.owner.html_url
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["html_url"]
    )
    assert (
        obj.base.repo.owner.followers_url
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["followers_url"]
    )
    assert (
        obj.base.repo.owner.following_url
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["following_url"]
    )
    assert (
        obj.base.repo.owner.gists_url
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["gists_url"]
    )
    assert (
        obj.base.repo.owner.starred_url
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["starred_url"]
    )
    assert (
        obj.base.repo.owner.subscriptions_url
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["subscriptions_url"]
    )
    assert (
        obj.base.repo.owner.organizations_url
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["organizations_url"]
    )
    assert (
        obj.base.repo.owner.repos_url
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["repos_url"]
    )
    assert (
        obj.base.repo.owner.events_url
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["events_url"]
    )
    assert (
        obj.base.repo.owner.received_events_url
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["received_events_url"]
    )
    assert obj.base.repo.owner.type == pullrequest_fixtrue_response["base"]["repo"]["owner"]["type"]
    assert (
        obj.base.repo.owner.site_admin
        == pullrequest_fixtrue_response["base"]["repo"]["owner"]["site_admin"]
    )
    assert obj.base.repo.private == pullrequest_fixtrue_response["base"]["repo"]["private"]
    assert obj.base.repo.html_url == pullrequest_fixtrue_response["base"]["repo"]["html_url"]
    assert obj.base.repo.description == pullrequest_fixtrue_response["base"]["repo"]["description"]
    assert obj.base.repo.fork == pullrequest_fixtrue_response["base"]["repo"]["fork"]
    assert obj.base.repo.url == pullrequest_fixtrue_response["base"]["repo"]["url"]
    assert obj.base.repo.archive_url == pullrequest_fixtrue_response["base"]["repo"]["archive_url"]
    assert (
        obj.base.repo.assignees_url == pullrequest_fixtrue_response["base"]["repo"]["assignees_url"]
    )
    assert obj.base.repo.blobs_url == pullrequest_fixtrue_response["base"]["repo"]["blobs_url"]
    assert (
        obj.base.repo.branches_url == pullrequest_fixtrue_response["base"]["repo"]["branches_url"]
    )
    assert (
        obj.base.repo.collaborators_url
        == pullrequest_fixtrue_response["base"]["repo"]["collaborators_url"]
    )
    assert (
        obj.base.repo.comments_url == pullrequest_fixtrue_response["base"]["repo"]["comments_url"]
    )
    assert obj.base.repo.commits_url == pullrequest_fixtrue_response["base"]["repo"]["commits_url"]
    assert obj.base.repo.compare_url == pullrequest_fixtrue_response["base"]["repo"]["compare_url"]
    assert (
        obj.base.repo.contents_url == pullrequest_fixtrue_response["base"]["repo"]["contents_url"]
    )
    assert (
        obj.base.repo.contributors_url
        == pullrequest_fixtrue_response["base"]["repo"]["contributors_url"]
    )
    assert (
        obj.base.repo.deployments_url
        == pullrequest_fixtrue_response["base"]["repo"]["deployments_url"]
    )
    assert (
        obj.base.repo.downloads_url == pullrequest_fixtrue_response["base"]["repo"]["downloads_url"]
    )
    assert obj.base.repo.events_url == pullrequest_fixtrue_response["base"]["repo"]["events_url"]
    assert obj.base.repo.forks_url == pullrequest_fixtrue_response["base"]["repo"]["forks_url"]
    assert (
        obj.base.repo.git_commits_url
        == pullrequest_fixtrue_response["base"]["repo"]["git_commits_url"]
    )
    assert (
        obj.base.repo.git_refs_url == pullrequest_fixtrue_response["base"]["repo"]["git_refs_url"]
    )
    assert (
        obj.base.repo.git_tags_url == pullrequest_fixtrue_response["base"]["repo"]["git_tags_url"]
    )
    assert obj.base.repo.git_url == pullrequest_fixtrue_response["base"]["repo"]["git_url"]
    assert (
        obj.base.repo.issue_comment_url
        == pullrequest_fixtrue_response["base"]["repo"]["issue_comment_url"]
    )
    assert (
        obj.base.repo.issue_events_url
        == pullrequest_fixtrue_response["base"]["repo"]["issue_events_url"]
    )
    assert obj.base.repo.issues_url == pullrequest_fixtrue_response["base"]["repo"]["issues_url"]
    assert obj.base.repo.keys_url == pullrequest_fixtrue_response["base"]["repo"]["keys_url"]
    assert obj.base.repo.labels_url == pullrequest_fixtrue_response["base"]["repo"]["labels_url"]
    assert (
        obj.base.repo.languages_url == pullrequest_fixtrue_response["base"]["repo"]["languages_url"]
    )
    assert obj.base.repo.merges_url == pullrequest_fixtrue_response["base"]["repo"]["merges_url"]
    assert (
        obj.base.repo.milestones_url
        == pullrequest_fixtrue_response["base"]["repo"]["milestones_url"]
    )
    assert (
        obj.base.repo.notifications_url
        == pullrequest_fixtrue_response["base"]["repo"]["notifications_url"]
    )
    assert obj.base.repo.pulls_url == pullrequest_fixtrue_response["base"]["repo"]["pulls_url"]
    assert (
        obj.base.repo.releases_url == pullrequest_fixtrue_response["base"]["repo"]["releases_url"]
    )
    assert obj.base.repo.ssh_url == pullrequest_fixtrue_response["base"]["repo"]["ssh_url"]
    assert (
        obj.base.repo.stargazers_url
        == pullrequest_fixtrue_response["base"]["repo"]["stargazers_url"]
    )
    assert (
        obj.base.repo.statuses_url == pullrequest_fixtrue_response["base"]["repo"]["statuses_url"]
    )
    assert (
        obj.base.repo.subscribers_url
        == pullrequest_fixtrue_response["base"]["repo"]["subscribers_url"]
    )
    assert (
        obj.base.repo.subscription_url
        == pullrequest_fixtrue_response["base"]["repo"]["subscription_url"]
    )
    assert obj.base.repo.tags_url == pullrequest_fixtrue_response["base"]["repo"]["tags_url"]
    assert obj.base.repo.teams_url == pullrequest_fixtrue_response["base"]["repo"]["teams_url"]
    assert obj.base.repo.trees_url == pullrequest_fixtrue_response["base"]["repo"]["trees_url"]
    assert obj.base.repo.clone_url == pullrequest_fixtrue_response["base"]["repo"]["clone_url"]
    assert obj.base.repo.mirror_url == pullrequest_fixtrue_response["base"]["repo"]["mirror_url"]
    assert obj.base.repo.hooks_url == pullrequest_fixtrue_response["base"]["repo"]["hooks_url"]
    assert obj.base.repo.svn_url == pullrequest_fixtrue_response["base"]["repo"]["svn_url"]
    assert obj.base.repo.homepage == pullrequest_fixtrue_response["base"]["repo"]["homepage"]
    assert obj.base.repo.language == pullrequest_fixtrue_response["base"]["repo"]["language"]
    assert obj.base.repo.forks_count == pullrequest_fixtrue_response["base"]["repo"]["forks_count"]
    assert (
        obj.base.repo.stargazers_count
        == pullrequest_fixtrue_response["base"]["repo"]["stargazers_count"]
    )
    assert (
        obj.base.repo.watchers_count
        == pullrequest_fixtrue_response["base"]["repo"]["watchers_count"]
    )
    assert obj.base.repo.size == pullrequest_fixtrue_response["base"]["repo"]["size"]
    assert (
        obj.base.repo.default_branch
        == pullrequest_fixtrue_response["base"]["repo"]["default_branch"]
    )
    assert (
        obj.base.repo.open_issues_count
        == pullrequest_fixtrue_response["base"]["repo"]["open_issues_count"]
    )
    assert obj.base.repo.is_template == pullrequest_fixtrue_response["base"]["repo"]["is_template"]
    assert obj.base.repo.topics[0] == pullrequest_fixtrue_response["base"]["repo"]["topics"][0]
    assert obj.base.repo.has_issues == pullrequest_fixtrue_response["base"]["repo"]["has_issues"]
    assert (
        obj.base.repo.has_projects == pullrequest_fixtrue_response["base"]["repo"]["has_projects"]
    )
    assert obj.base.repo.has_wiki == pullrequest_fixtrue_response["base"]["repo"]["has_wiki"]
    assert obj.base.repo.has_pages == pullrequest_fixtrue_response["base"]["repo"]["has_pages"]
    assert (
        obj.base.repo.has_downloads == pullrequest_fixtrue_response["base"]["repo"]["has_downloads"]
    )
    assert obj.base.repo.archived == pullrequest_fixtrue_response["base"]["repo"]["archived"]
    assert obj.base.repo.disabled == pullrequest_fixtrue_response["base"]["repo"]["disabled"]
    assert obj.base.repo.visibility == pullrequest_fixtrue_response["base"]["repo"]["visibility"]
    assert obj.base.repo.pushed_at == pullrequest_fixtrue_response["base"]["repo"]["pushed_at"]
    assert obj.base.repo.created_at == pullrequest_fixtrue_response["base"]["repo"]["created_at"]
    assert obj.base.repo.updated_at == pullrequest_fixtrue_response["base"]["repo"]["updated_at"]
    assert (
        obj.base.repo.permissions.admin
        == pullrequest_fixtrue_response["base"]["repo"]["permissions"]["admin"]
    )
    assert (
        obj.base.repo.permissions.push
        == pullrequest_fixtrue_response["base"]["repo"]["permissions"]["push"]
    )
    assert (
        obj.base.repo.permissions.pull
        == pullrequest_fixtrue_response["base"]["repo"]["permissions"]["pull"]
    )
    assert (
        obj.base.repo.allow_rebase_merge
        == pullrequest_fixtrue_response["base"]["repo"]["allow_rebase_merge"]
    )
    assert (
        obj.base.repo.template_repository
        == pullrequest_fixtrue_response["base"]["repo"]["template_repository"]
    )
    assert (
        obj.base.repo.temp_clone_token
        == pullrequest_fixtrue_response["base"]["repo"]["temp_clone_token"]
    )
    assert (
        obj.base.repo.allow_squash_merge
        == pullrequest_fixtrue_response["base"]["repo"]["allow_squash_merge"]
    )
    assert (
        obj.base.repo.delete_branch_on_merge
        == pullrequest_fixtrue_response["base"]["repo"]["delete_branch_on_merge"]
    )
    assert (
        obj.base.repo.allow_merge_commit
        == pullrequest_fixtrue_response["base"]["repo"]["allow_merge_commit"]
    )
    assert (
        obj.base.repo.subscribers_count
        == pullrequest_fixtrue_response["base"]["repo"]["subscribers_count"]
    )
    assert (
        obj.base.repo.network_count == pullrequest_fixtrue_response["base"]["repo"]["network_count"]
    )
    assert obj.author_association == pullrequest_fixtrue_response["author_association"]
    assert obj.draft == pullrequest_fixtrue_response["draft"]
    assert obj.merged == pullrequest_fixtrue_response["merged"]
    assert obj.mergeable == pullrequest_fixtrue_response["mergeable"]
    assert obj.rebaseable == pullrequest_fixtrue_response["rebaseable"]
    assert obj.mergeable_state == pullrequest_fixtrue_response["mergeable_state"]
    assert obj.merged_by.login == pullrequest_fixtrue_response["merged_by"]["login"]
    assert obj.merged_by.id == pullrequest_fixtrue_response["merged_by"]["id"]
    assert obj.merged_by.node_id == pullrequest_fixtrue_response["merged_by"]["node_id"]
    assert obj.merged_by.avatar_url == pullrequest_fixtrue_response["merged_by"]["avatar_url"]
    assert obj.merged_by.gravatar_id == pullrequest_fixtrue_response["merged_by"]["gravatar_id"]
    assert obj.merged_by.url == pullrequest_fixtrue_response["merged_by"]["url"]
    assert obj.merged_by.html_url == pullrequest_fixtrue_response["merged_by"]["html_url"]
    assert obj.merged_by.followers_url == pullrequest_fixtrue_response["merged_by"]["followers_url"]
    assert obj.merged_by.following_url == pullrequest_fixtrue_response["merged_by"]["following_url"]
    assert obj.merged_by.gists_url == pullrequest_fixtrue_response["merged_by"]["gists_url"]
    assert obj.merged_by.starred_url == pullrequest_fixtrue_response["merged_by"]["starred_url"]
    assert (
        obj.merged_by.subscriptions_url
        == pullrequest_fixtrue_response["merged_by"]["subscriptions_url"]
    )
    assert (
        obj.merged_by.organizations_url
        == pullrequest_fixtrue_response["merged_by"]["organizations_url"]
    )
    assert obj.merged_by.repos_url == pullrequest_fixtrue_response["merged_by"]["repos_url"]
    assert obj.merged_by.events_url == pullrequest_fixtrue_response["merged_by"]["events_url"]
    assert (
        obj.merged_by.received_events_url
        == pullrequest_fixtrue_response["merged_by"]["received_events_url"]
    )
    assert obj.merged_by.type == pullrequest_fixtrue_response["merged_by"]["type"]
    assert obj.merged_by.site_admin == pullrequest_fixtrue_response["merged_by"]["site_admin"]
    assert obj.comments == pullrequest_fixtrue_response["comments"]
    assert obj.review_comments == pullrequest_fixtrue_response["review_comments"]
    assert obj.maintainer_can_modify == pullrequest_fixtrue_response["maintainer_can_modify"]
    assert obj.commits == pullrequest_fixtrue_response["commits"]
    assert obj.additions == pullrequest_fixtrue_response["additions"]
    assert obj.deletions == pullrequest_fixtrue_response["deletions"]
    assert obj.changed_files == pullrequest_fixtrue_response["changed_files"]
