"""
Generated by generate/generate.py - 2020-08-02 10:33:09.248066
"""
from aiogithubapi.objects.orgs.team import AIOGitHubAPIOrgsTeam

from tests.legacy.responses.orgs.team_fixtrue import team_fixtrue_response


def test_team(team_fixtrue_response):
    obj = AIOGitHubAPIOrgsTeam(team_fixtrue_response)
    assert obj.id == team_fixtrue_response["id"]
    assert obj.node_id == team_fixtrue_response["node_id"]
    assert obj.url == team_fixtrue_response["url"]
    assert obj.html_url == team_fixtrue_response["html_url"]
    assert obj.name == team_fixtrue_response["name"]
    assert obj.slug == team_fixtrue_response["slug"]
    assert obj.description == team_fixtrue_response["description"]
    assert obj.privacy == team_fixtrue_response["privacy"]
    assert obj.permission == team_fixtrue_response["permission"]
    assert obj.members_url == team_fixtrue_response["members_url"]
    assert obj.repositories_url == team_fixtrue_response["repositories_url"]
    assert obj.parent == team_fixtrue_response["parent"]
    assert obj.members_count == team_fixtrue_response["members_count"]
    assert obj.repos_count == team_fixtrue_response["repos_count"]
    assert obj.created_at == team_fixtrue_response["created_at"]
    assert obj.updated_at == team_fixtrue_response["updated_at"]
    assert obj.organization.login == team_fixtrue_response["organization"]["login"]
    assert obj.organization.id == team_fixtrue_response["organization"]["id"]
    assert obj.organization.node_id == team_fixtrue_response["organization"]["node_id"]
    assert obj.organization.url == team_fixtrue_response["organization"]["url"]
    assert obj.organization.repos_url == team_fixtrue_response["organization"]["repos_url"]
    assert obj.organization.events_url == team_fixtrue_response["organization"]["events_url"]
    assert obj.organization.hooks_url == team_fixtrue_response["organization"]["hooks_url"]
    assert obj.organization.issues_url == team_fixtrue_response["organization"]["issues_url"]
    assert obj.organization.members_url == team_fixtrue_response["organization"]["members_url"]
    assert (
        obj.organization.public_members_url
        == team_fixtrue_response["organization"]["public_members_url"]
    )
    assert obj.organization.avatar_url == team_fixtrue_response["organization"]["avatar_url"]
    assert obj.organization.description == team_fixtrue_response["organization"]["description"]
    assert obj.organization.name == team_fixtrue_response["organization"]["name"]
    assert obj.organization.company == team_fixtrue_response["organization"]["company"]
    assert obj.organization.blog == team_fixtrue_response["organization"]["blog"]
    assert obj.organization.location == team_fixtrue_response["organization"]["location"]
    assert obj.organization.email == team_fixtrue_response["organization"]["email"]
    assert (
        obj.organization.twitter_username
        == team_fixtrue_response["organization"]["twitter_username"]
    )
    assert obj.organization.is_verified == team_fixtrue_response["organization"]["is_verified"]
    assert (
        obj.organization.has_organization_projects
        == team_fixtrue_response["organization"]["has_organization_projects"]
    )
    assert (
        obj.organization.has_repository_projects
        == team_fixtrue_response["organization"]["has_repository_projects"]
    )
    assert obj.organization.public_repos == team_fixtrue_response["organization"]["public_repos"]
    assert obj.organization.public_gists == team_fixtrue_response["organization"]["public_gists"]
    assert obj.organization.followers == team_fixtrue_response["organization"]["followers"]
    assert obj.organization.following == team_fixtrue_response["organization"]["following"]
    assert obj.organization.html_url == team_fixtrue_response["organization"]["html_url"]
    assert obj.organization.created_at == team_fixtrue_response["organization"]["created_at"]
    assert obj.organization.type == team_fixtrue_response["organization"]["type"]
