"""
Generated by generate/generate.py - 2020-09-08 18:45:20.581868
"""
import pytest


@pytest.fixture()
def oauth_fixtrue_response():
    return {
        "access_token": "e72e16c7e42f292c6912e7710c838347ae178b4a",
        "token_type": "bearer",
        "scope": "user",
    }
