"""
Generated by generate/generate.py - 2020-09-08 17:49:51.525706
"""
from aiogithubapi.objects.login.device import AIOGitHubAPILoginDevice

from tests.legacy.responses.login.device_fixtrue import device_fixtrue_response


def test_device(device_fixtrue_response):
    obj = AIOGitHubAPILoginDevice(device_fixtrue_response)
    assert obj.device_code == device_fixtrue_response["device_code"]
    assert obj.user_code == device_fixtrue_response["user_code"]
    assert obj.verification_uri == device_fixtrue_response["verification_uri"]
    assert obj.expires_in == device_fixtrue_response["expires_in"]
    assert obj.interval == device_fixtrue_response["interval"]
