"""
Generated by generate/generate.py - 2020-09-08 17:49:51.525706
"""
import pytest


@pytest.fixture()
def device_fixtrue_response():
    return {
        "device_code": "3584d83530557fdd1f46af8289938c8ef79f9dc5",
        "user_code": "WDJB-MJHT",
        "verification_uri": "https://github.com/login/device",
        "expires_in": 900,
        "interval": 5,
    }
