"""
Generated by generate/generate.py - 2020-08-02 12:24:23.865974
"""
from aiogithubapi.objects.repos.traffic.clones import AIOGitHubAPIReposTrafficClones

from tests.legacy.responses.repos.traffic.clones_fixtrue import clones_fixtrue_response


def test_clones(clones_fixtrue_response):
    obj = AIOGitHubAPIReposTrafficClones(clones_fixtrue_response)
    assert obj.count == clones_fixtrue_response["count"]
    assert obj.uniques == clones_fixtrue_response["uniques"]
    assert obj.clones[0].timestamp == clones_fixtrue_response["clones"][0]["timestamp"]
    assert obj.clones[0].count == clones_fixtrue_response["clones"][0]["count"]
    assert obj.clones[0].uniques == clones_fixtrue_response["clones"][0]["uniques"]
