"""
Generated by generate/generate.py - 2020-08-02 10:32:07.005845
"""
import pytest


@pytest.fixture()
def label_fixtrue_response():
    return {
        "id": 208045946,
        "node_id": "MDU6TGFiZWwyMDgwNDU5NDY=",
        "url": "https://api.github.com/repos/octocat/Hello-World/labels/bug",
        "name": "bug",
        "description": "Something isn't working",
        "color": "f29513",
        "default": True,
    }
