"""
Generated by generate/generate.py - 2020-08-02 10:32:07.005845
"""
from aiogithubapi.objects.repos.label import AIOGitHubAPIReposLabel

from tests.legacy.responses.repos.label_fixtrue import label_fixtrue_response


def test_label(label_fixtrue_response):
    obj = AIOGitHubAPIReposLabel(label_fixtrue_response)
    assert obj.id == label_fixtrue_response["id"]
    assert obj.node_id == label_fixtrue_response["node_id"]
    assert obj.url == label_fixtrue_response["url"]
    assert obj.name == label_fixtrue_response["name"]
    assert obj.description == label_fixtrue_response["description"]
    assert obj.color == label_fixtrue_response["color"]
    assert obj.default == label_fixtrue_response["default"]
